@@ -12,13 +12,14 @@ def current_user() -> str:
 
 
 def get_user_full_name(username: str) -> str:
-    """Returns full name of user"""
-    full_name = ",,,"
-    user_file = "/etc/passwd"
-    with open(user_file) as f:
+    """Returns a user's full name given a username or original value if not found"""
+    full_name = username
+    with open("/etc/passwd") as f:
         for line in f:
-            if line.startswith(username):
-                full_name = line.split(":")[4]
+            if line.split(":")[0] == username:
+                full_name = line.split(":")[4].strip("/n")
                 break
-    full_name = "unknown" if full_name == ",,," else full_name
-    return full_name
+    if full_name:
+        full_name = full_name.replace(",,,", "")
+        return full_name
+    return username
